============================
Example Code from Repository
============================

All examples documented in this section are available from the
GitHub repository within the ``examples`` folder:
https://github.com/SPOpenSource/edgeconnect-python/tree/main/examples

Example script documentation and instructions

.. toctree::
   :maxdepth: 2

   auth_example
   basic_examples
   generate_preconfig